starcluster.optcomplete.NoneCompleter

Package starcluster :: Module optcomplete :: Class NoneCompleter |
[hide private]
[frames] | no frames]

# Class NoneCompleter

source code

Generates empty completion list.

Instance Methods | [hide private]
__call__(self, pwd, line, point, prefix, suffix) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`